﻿// Click&Find
// Version: 12.03
// Copyright(c) by ELO Digital Office GmbH, 22.04.2020
//
// This script implements the click and find functionality
// in the ELO Java Client
//

importPackage(Packages.de.elo.ix.client);

var HOTKEY = "alt T";
var DO_ESEARCH = false;

var SEARCH_IN_FULLTEXT = true;
var SEARCH_IN_INDEX = true;
var SEARCH_IN_MEMO = true;
var SEARCH_IN_NAME = true;

var VIEWNAME = "EloCaFSearchView";

function eloWorkspaceStarted() {
  workspace.addHotKey(HOTKEY, "clickAndFindSearch");
} 
 
function clickAndFindSearch() {
  var result = utils.transferByClipboard(false, true);
  
  workspace.setFeedbackMessage("Search Version: " + result);
  var view = searchViews.getSearchView(VIEWNAME);
  if (!view) {
	view = searchViews.addSearchView(VIEWNAME);
  }
  
  directSearch(view, result);
  view.setSearchTerm(result);
  workspace.toFront();
}

function directSearch(view, searchText) {
  try {
    view.runSearch(searchText, false);
  } catch(e) {
    log.info("Error while running the ELO Client search");
  }
  
  var findInfo = new FindInfo();
  var findOptions = view.createFindOptions();
  findInfo.findOptions = findOptions;
  
  if (DO_ESEARCH) {
    var findByFulltext = new FindByFulltext();
    findByFulltext.term = searchText;
    
    findInfo.findByFulltext = findByFulltext;
  } else {
    var findDirect = new FindDirect();
    findDirect.query = searchText;
    findDirect.searchInFulltext = SEARCH_IN_FULLTEXT;
    findDirect.searchInIndex = SEARCH_IN_INDEX;
    findDirect.searchInMemo = SEARCH_IN_MEMO;
    findDirect.searchInSordName = SEARCH_IN_NAME;
    
    findInfo.findDirect = findDirect;
  }
  
  view.startSearch( findInfo, true );
}

